# Evenv: Embeddable Virtual Environment Builder

## Project Description

**Evenv** is a powerful Python virtual environment manager designed to create embeddable Python environments with enhanced flexibility. It allows users to include or exclude specific features like `tkinter`, offering fine-grained control over the environment's configuration. Built to address the needs of developers requiring highly customized environments, Evenv simplifies the management of dependencies, configurations, and system compatibility issues.

## Key Features

- **Customizable Build Options**: Create virtual environments with or without `tkinter` or `pip`.
- **Flexible Configuration**: Generate environments with customizable prompts, Python version compatibility, and pip pre-installation.
- **Cross-Platform Compatibility**: Supports symlinks and file copying across different operating systems.
- **Integration with Source Control**: Optionally generate `.gitignore` files for seamless source control management.

## Installation

### Prerequisites

- **Python**: Version 3.9 or later.
- **OS**: Compatible with Windows.
- **Dependencies**: Ensure the `venv` package is available in your Python environment.

### Installation Steps

1. Install from pypi:

   ```powershell
   pip install -U evenv
   ```

2. Verify the installation:
   ```powershell
   python -m evenv --help
   ```

## Usage

### Basic Usage

To create a new virtual environment:

```powershell
python -m evenv my_env
```

### Advanced Options

- Exclude `tkinter`:
  ```powershell
  python -m evenv my_env --without-tk
  ```
- Customize the prompt:
  ```powershell
  python -m evenv my_env --prompt "CustomEnv"
  ```

### Example

```powershell
python -m evenv my_project_env --without-tk --prompt "MyProject"
my_project_env\Scripts\activate
```
